<?php

/** 
 * Plugin name: GVSoft Photobox
 * Description: Фоторамка для просмотра фотографий и картинок. Photo frame for viewing photos and pictures.
 * 
 * Text Domain: gvsoft-photobox
 * Domain Path: /languages
 * 
 * Author: Vladimir Giryavyy
 * Author URI: http://gvsoft.ru/
 * Plugin URI: http://gvsoft.ru/development/wordpress-plugins/photobox
 * 
 * Version: 1.2.1
 */

if( ! defined('ABSPATH') ) die('-1'); // no direct access

if( defined('WP_INSTALLING') && WP_INSTALLING ) return;

$data = get_file_data( __FILE__, array('Version'=>'Version', 'Domain Path'=>'Domain Path') );

define('GVPB_VER',  $data['Version'] );

define('GVPB_PATH', plugin_dir_path(__FILE__) );
define('GVPB_URL',  plugin_dir_url(__FILE__) );
define('GVPB_NAME', basename(GVPB_PATH) ); // folder name - gvsoft-photobox


// Подключаем файл перевода
add_action( 'plugins_loaded', function() {
    load_plugin_textdomain( 'gvsoft-photobox', false, GVPB_NAME . '/languages' ); 
});

if ( is_admin() ) { // Если мы в адм. интерфейсе
    require_once GVPB_PATH . 'admin.php';
    return;
}

// Подключаем скрипты и css стили
add_action('wp_enqueue_scripts', function(){
    wp_enqueue_script('gvphotobox', GVPB_URL . 'jquery.gvphotobox-1.0.1.js', array('jquery'));
});

// Применяем переменные к шаблону стилей
add_action('wp_head', function(){
    require GVPB_PATH . 'defparam.php';
    $border_color = esc_attr( get_option('gvpb_border_color',$gvpb_def_params['gvpb_border_color']) );
    $button_color = esc_attr( get_option('gvpb_button_color',$gvpb_def_params['gvpb_button_color']) );
    $label_color = esc_attr( get_option('gvpb_label_color',$gvpb_def_params['gvpb_label_color']) );
    $border_radius = esc_attr( get_option('gvpb_border_radius',$gvpb_def_params['gvpb_border_radius']) );
    $border_width = esc_attr( get_option('gvpb_border_width',$gvpb_def_params['gvpb_border_width']) );
    ob_start();
    try {
        include_once GVPB_PATH . 'gvphotobox.css.tpl';
    }
    catch (Exception $e) {
        ob_end_clean(); // Delete the output buffer
        throw $e; // Re-throw the exception
    }
    echo '<style type="text/css">'.ob_get_clean().'</style>'; // Get the captured output and close the buffer    
}); 

add_action('wp_footer', function(){
    require GVPB_PATH . 'defparam.php';
    
    $animation = (boolean) get_option('gvpb_animation',$gvpb_def_params['gvpb_animation']);
    $jsanim = $animation === FALSE ? 'false' : 'true';
?>
<script type="text/javascript">
    jQuery(".gallery").gvphotobox({
        delay:<?= esc_attr( get_option('gvpb_delay',$gvpb_def_params['gvpb_delay']) ) ?>,
        indicator:null,
        <?php
        if (TRUE === $animation) {?>
        animation:<?= $jsanim ?>,
        speedOldImgAnim:'<?= esc_attr( get_option('gvpb_speedOldImgAnim',$gvpb_def_params['gvpb_speedOldImgAnim']) )?>',
        speedNewImgAnim:'<?= esc_attr( get_option('gvpb_speedNewImgAnim',$gvpb_def_params['gvpb_speedNewImgAnim']) )?>',
        oldImgAnim:'<?= esc_attr( get_option('gvpb_OldImgAnim',$gvpb_def_params['gvpb_OldImgAnim']) )?>',
        newImgAnim:'<?= esc_attr( get_option('gvpb_NewImgAnim',$gvpb_def_params['gvpb_NewImgAnim']) )?>',
        <?php }
        ?>
    });
</script>
<?php
});